@@ -5,12 +5,8 @@ import json
 
 from distkv.util import yprint, NotGiven, yload, P, Path
 
-import logging
 
-logger = logging.getLogger(__name__)
-
-
-@main.group()  # pylint: disable=undefined-variable
+@click.group()  # pylint: disable=undefined-variable
 async def cli():
     """Manage types and type matches. Usage: … type …"""
     pass
