@@ -73,7 +73,7 @@ async def stdtest(n=1, run=True, ssl=False, tocks=20, **kw):
         s = st.s[i]
         await s.is_serving
         for host, port, *_ in s.ports:
-            if host[0] != ":":
+            if host == "::" or host[0] != ":":
                 return host, port
 
     def tm():
@@ -129,17 +129,17 @@ async def stdtest(n=1, run=True, ssl=False, tocks=20, **kw):
             evts = []
             for i in range(n):
                 if kw.get("run_" + str(i), run):
-                    evt = anyio.create_event()
-                    await tg.spawn(partial(st.s[i].serve, ready_evt=evt))
+                    evt = anyio.Event()
+                    tg.spawn(partial(st.s[i].serve, ready_evt=evt))
                     evts.append(evt)
             for e in evts:
                 await e.wait()
             try:
                 yield st
             finally:
-                async with anyio.fail_after(2, shield=True):
+                with anyio.fail_after(2, shield=True):
                     logger.info("Runtime: %s", clock.current_time())
-                    await tg.cancel_scope.cancel()
+                    tg.cancel_scope.cancel()
         logger.info("End")
         pass  # unwinding ex:AsyncExitStack
 
@@ -168,12 +168,12 @@ class MockServ:
 
     async def spawn(self, fn, *args, **kw):
         async def run(evt):
-            async with anyio.open_cancel_scope() as sc:
+            with anyio.CancelScope() as sc:
                 await evt.set(sc)
                 await fn(*args, **kw)
 
         evt = ValueEvent()
-        await self._tg.spawn(run, evt)
+        self._tg.spawn(run, evt)
         return await evt.get()
 
     async def event(self, name, payload, coalesce=True):
