@@ -2642,7 +2642,7 @@ class Server:
 
                 self._ready2.set()
                 if ready_evt is not None:
-                    await ready_evt.set()
+                    ready_evt.set()
                 pass  # end of server taskgroup
             pass  # end of server
         pass  # end of serf client
