@@ -1,17 +1,14 @@
 """
 This module contains various helper functions and classes.
 """
-import re
-
-import collections.abc
 import ast
-
-from typing import Union
+import collections.abc
+import logging
+import re
 from functools import total_ordering
+from typing import Union
 
 import simpleeval
-import logging
-
 
 __all__ = ["Path", "P", "logger_for", "PathShortener", "PathLongener", "path_eval"]
 
@@ -285,7 +282,16 @@ class Path(collections.abc.Sequence):
 
 
 class P(Path):
+    """
+    A Path subclass that delegates to `Path.from_str`.
+
+    For idempotency (required by ``click``) it transparently accepts `Path`
+    objects.
+    """
+
     def __new__(cls, path):
+        if isinstance(path, Path):
+            return path
         return Path.from_str(path)
 
 
